PyBEL Tools |develop_build| |develop_coverage| |develop_documentation| |zenodo|
===============================================================================
`PyBEL Tools <https://pybel-tools.readthedocs.io/>`_ is a suite of tools built on top of
`PyBEL <https://pybel.readthedocs.io>`_ to facilitate data management, integration, and analysis.

This package was developed at `Fraunhofer SCAI <https://www.scai.fraunhofer.de/>`_
with support from the `IMI <https://www.imi.europa.eu/>`_ projects: `AETIONOMY <http://www.aetionomy.eu/>`_ and
`PHAGO <http://www.phago.eu/>`_.

Installation |pypi_version| |python_versions| |pypi_license|
------------------------------------------------------------
PyBEL Tools can be installed easily from PyPI_ with the following code in
your favorite terminal:

.. code-block:: sh

    $ python3 -m pip install pybel_tools

or from the latest code on `GitHub <https://github.com/pybel/pybel-tools>`_ with:

.. code-block:: sh

    $ python3 -m pip install git+https://github.com/pybel/pybel-tools.git@develop

Documentation and Examples
--------------------------
- Documentation at https://pybel-tools.readthedocs.io
- Cookbook at https://github.com/pybel/pybel-notebooks

Links
-----
- Documented on `Read the Docs <https://pybel-tools.readthedocs.io/>`_
- Versioned on `GitHub <https://github.com/pybel/pybel-tools>`_
- Tested on `Travis CI <https://travis-ci.org/pybel/pybel-tools>`_
- Distributed by PyPI_
- Chat on `Gitter <https://gitter.im/pybel/Lobby>`_


.. _PyPI: https://pypi.python.org/pypi/pybel_tools

.. |develop_build| image:: https://travis-ci.org/pybel/pybel-tools.svg?branch=develop
    :target: https://travis-ci.org/pybel/pybel-tools
    :alt: Development Build Status

.. |develop_coverage| image:: https://codecov.io/gh/pybel/pybel-tools/coverage.svg?branch=develop
    :target: https://codecov.io/gh/pybel/pybel-tools?branch=develop
    :alt: Development Coverage Status

.. |develop_documentation| image:: https://readthedocs.org/projects/pybel-tools/badge/?version=latest
    :target: http://pybel-tools.readthedocs.io/en/latest/
    :alt: Development Documentation Status

.. |python_versions| image:: https://img.shields.io/pypi/pyversions/pybel-tools.svg
    :alt: Stable Supported Python Versions

.. |pypi_version| image:: https://img.shields.io/pypi/v/pybel-tools.svg
    :alt: Current version on PyPI

.. |pypi_license| image:: https://img.shields.io/pypi/l/pybel-tools.svg
    :alt: Apache 2.0 License

.. |zenodo| image:: https://zenodo.org/badge/70473008.svg
    :target: https://zenodo.org/badge/latestdoi/70473008